tl.dot performs block-level matrix multiplication using tensor cores in Triton
Image: Daniel L. Lu (user:dllu), CC BY-SA 4.0, via Wikimedia Commons
tl.dot performs block-level matrix multiplication using tensor cores in Triton
tensor cores do 4x4 matrix multiply in one clock cycle
Tensor cores perform 4x4 matrix multiply using optimized GEMM (General Matrix Multiply) instructions in one clock cycle
tl.load and tl.store do in Triton: read/write tensors from/to GPU global memory
`tl.load` reads tensors from GPU memory; `tl.store` writes tensors to GPU memory
to write a vector addition kernel in Triton: load blocks, add, store
```
tensor cores are
Why can computers crunch numbers faster than humans?
Triton differs from CUDA
Why does a super-fast computer sometimes run slower than a regular one?
a Triton @triton.jit decorator does: compiles a Python function into a GPU kernel
@triton.jit decorator compiles Python function into a GPU kernel
Swipe through 100 ML concepts daily
Open Pocket Polymath